__license__     = 'GPLv3'
__author__      = 'Alberto Pettarin (pettarin gmail.com)'
__copyright__   = '2011 Alberto Pettarin (pettarin gmail.com)'
__version__     = 'v1.02'
__date__        = '2011-09-28'
__description__ = 'Fix the footnote links/backlinks generated by TeX4ht. Input from stdin and output to stdout.'


import sys
import string

# read from stdin
data = sys.stdin.read()

# match footnote endlabel
endLabel="<!--endlabel-->"
occurrenceEndLabel = 0

# match math tag
openingMathTag="<math"
occurrenceOpeningMathTag = 0
closingMathTag="</math>"
occurrenceClosingMathTag = 0

# match footnote number
openingNumberTag = "<mn>"
occurrenceOpeningNumberTag = 0
closingNumberTag = "</mn>"
occurrenceClosingNumberTag = 0

# match ennote tag
openingEnnoteTag="xlink:href=\""
occurrenceOpeningEnnoteTag = 0
closingEnnoteTag="\""
occurrenceClosingEnnoteTag = 0

# match enmark tag
openingEnmarkTag="id=\""
occurrenceOpeningEnmarkTag = 0
closingEnmarkTag="\""
occurrenceClosingEnmarkTag = 0

# match and replace
while True:
    occurrenceEndLabel = data.find(endLabel, occurrenceEndLabel)
    if (occurrenceEndLabel < 0):
        break
    
    # get the starting position of the math block to be substituted
    occurrenceOpeningMathTag = data.rfind(openingMathTag, 0, occurrenceEndLabel)
    
    # get the ending position of the math block to be substituted
    occurrenceClosingMathTag = data.find(closingMathTag, occurrenceOpeningMathTag) + len(closingMathTag)

    # get the starting position of the footnote number
    occurrenceOpeningNumberTag = data.find(openingNumberTag, occurrenceOpeningMathTag) + len(openingNumberTag)

    # get the ending position of the footnote number
    occurrenceClosingNumberTag = data.rfind(closingNumberTag, 0, occurrenceEndLabel)
    
    # get the starting position of the ennote tag
    occurrenceOpeningEnnoteTag = data.find(openingEnnoteTag, occurrenceOpeningMathTag) + len(openingEnnoteTag)

    # get the ending position of the ennote tag
    occurrenceClosingEnnoteTag = data.find(closingEnnoteTag, occurrenceOpeningEnnoteTag)

    # get the starting position of the enmark tag
    occurrenceOpeningEnmarkTag = data.find(openingEnmarkTag, occurrenceOpeningMathTag) + len(openingEnmarkTag)

    # get the ending position of the enmark tag
    occurrenceClosingEnmarkTag = data.find(closingEnmarkTag, occurrenceOpeningEnmarkTag)

    # get the footnote/backref id
    ennoteTag = data[occurrenceOpeningEnnoteTag : occurrenceClosingEnnoteTag]
    enmarkTag = data[occurrenceOpeningEnmarkTag : occurrenceClosingEnmarkTag]

    # get the footnote number
    footnoteNumber = data[occurrenceOpeningNumberTag : occurrenceClosingNumberTag]
    footnoteNumber = string.replace(footnoteNumber, openingNumberTag, "")
    footnoteNumber = string.replace(footnoteNumber, closingNumberTag, "")

    # replace the footnote link, inserting it as [x]
    oldString = data[occurrenceOpeningMathTag : occurrenceClosingMathTag] 
    newString = ' <a href="'+ ennoteTag + '" id="' + enmarkTag + '">[' + footnoteNumber + ']</a>'
    data = string.replace(data, oldString, newString)

    # loop!
    occurrenceEndLabel += 1

# print to stdout
print data

